pitchtools.Octave
=================

.. abjad-lineage:: abjad.tools.pitchtools.Octave.Octave

.. autoclass:: abjad.tools.pitchtools.Octave.Octave

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.Octave.Octave.from_pitch_name
      ~abjad.tools.pitchtools.Octave.Octave.from_pitch_number
      ~abjad.tools.pitchtools.Octave.Octave.is_octave_tick_string
      ~abjad.tools.pitchtools.Octave.Octave.octave_number
      ~abjad.tools.pitchtools.Octave.Octave.octave_tick_string
      ~abjad.tools.pitchtools.Octave.Octave.pitch_number
      ~abjad.tools.pitchtools.Octave.Octave.pitch_range
      ~abjad.tools.pitchtools.Octave.Octave.__eq__
      ~abjad.tools.pitchtools.Octave.Octave.__float__
      ~abjad.tools.pitchtools.Octave.Octave.__format__
      ~abjad.tools.pitchtools.Octave.Octave.__hash__
      ~abjad.tools.pitchtools.Octave.Octave.__int__
      ~abjad.tools.pitchtools.Octave.Octave.__ne__
      ~abjad.tools.pitchtools.Octave.Octave.__repr__
      ~abjad.tools.pitchtools.Octave.Octave.__str__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.Octave.Octave.octave_number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Octave.Octave.octave_tick_string
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Octave.Octave.pitch_number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Octave.Octave.pitch_range
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.pitchtools.Octave.Octave.from_pitch_name
   :noindex:

.. automethod:: abjad.tools.pitchtools.Octave.Octave.from_pitch_number
   :noindex:

.. automethod:: abjad.tools.pitchtools.Octave.Octave.is_octave_tick_string
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.Octave.Octave.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Octave.Octave.__float__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Octave.Octave.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Octave.Octave.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Octave.Octave.__int__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Octave.Octave.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Octave.Octave.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Octave.Octave.__str__
   :noindex:
